@@ -20,27 +20,15 @@ import errno
 from stat import S_ISDIR
 
 import breezy.branch
-from breezy import (
-    controldir,
-    errors,
-    repository,
-    revision as _mod_revision,
-    transport,
-    workingtree,
-    )
-from breezy.bzr import (
-    bzrdir,
-    )
+from breezy import controldir, errors, repository
+from breezy import revision as _mod_revision
+from breezy import transport, workingtree
+from breezy.bzr import bzrdir
 from breezy.bzr.remote import RemoteBzrDirFormat
-from breezy.tests import (
-    TestNotApplicable,
-    TestSkipped,
-    )
 from breezy.bzr.tests.per_bzrdir import TestCaseWithBzrDir
+from breezy.tests import TestNotApplicable, TestSkipped
 from breezy.transport import FileExists
-from breezy.transport.local import (
-    LocalTransport,
-    )
+from breezy.transport.local import LocalTransport
 
 
 class AnonymousTestBranchFormat(breezy.branch.BranchFormat):
@@ -461,7 +449,7 @@ class TestBzrDir(TestCaseWithBzrDir):
             with open(local_inventory, 'rb') as inventory_f:
                 self.assertContainsRe(inventory_f.read(),
                                       b'<inventory format="5">\n</inventory>\n')
-        except IOError as e:
+        except OSError as e:
             if e.errno != errno.ENOENT:
                 raise
 
