@@ -15,51 +15,25 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-"""An adapter between a Git Repository and a Bazaar Branch"""
+"""An adapter between a Git Repository and a Breezy one."""
 
 from io import BytesIO
 
-from .. import (
-    check,
-    errors,
-    graph as _mod_graph,
-    lock,
-    repository,
-    revision as _mod_revision,
-    trace,
-    transactions,
-    ui,
-    )
+from dulwich.errors import NotCommitError
+from dulwich.object_store import peel_sha, tree_lookup_path
+from dulwich.objects import ZERO_SHA, Commit
+
+from .. import check, errors
+from .. import graph as _mod_graph
+from .. import lock, repository
+from .. import revision as _mod_revision
+from .. import trace, transactions, ui
 from ..decorators import only_raises
-from ..foreign import (
-    ForeignRepository,
-    )
-
-from .filegraph import (
-    GitFileLastChangeScanner,
-    GitFileParentProvider,
-    )
-from .mapping import (
-    default_mapping,
-    encode_git_path,
-    foreign_vcs_git,
-    mapping_registry,
-    )
-from .tree import (
-    GitRevisionTree,
-    )
-
-
-from dulwich.errors import (
-    NotCommitError,
-    )
-from dulwich.objects import (
-    Commit,
-    ZERO_SHA,
-    )
-from dulwich.object_store import (
-    tree_lookup_path,
-    )
+from ..foreign import ForeignRepository
+from .filegraph import GitFileLastChangeScanner, GitFileParentProvider
+from .mapping import (default_mapping, encode_git_path, foreign_vcs_git,
+                      mapping_registry)
+from .tree import GitRevisionTree
 
 
 class GitCheck(check.Check):
@@ -88,7 +62,7 @@ class GitCheck(check.Check):
                     self.problems.append((sha, e))
 
     def _report_repo_results(self, verbose):
-        trace.note('checked repository {0} format {1}'.format(
+        trace.note('checked repository {} format {}'.format(
             self.repository.user_url,
             self.repository._format))
         trace.note('%6d objects', self.object_count)
@@ -115,13 +89,12 @@ for optimiser in ['InterRemoteGitNonGitRepository',
 class GitRepository(ForeignRepository):
     """An adapter to git repositories for bzr."""
 
-    _serializer = None
     vcs = foreign_vcs_git
     chk_bytes = None
 
     def __init__(self, gitdir):
         self._transport = gitdir.root_transport
-        super(GitRepository, self).__init__(GitRepositoryFormat(),
+        super().__init__(GitRepositoryFormat(),
                                             gitdir, control_files=None)
         self.base = gitdir.root_transport.base
         self._lock_mode = None
@@ -186,6 +159,8 @@ class GitRepository(ForeignRepository):
             transaction = self._transaction
             self._transaction = None
             transaction.finish()
+            if hasattr(self, '_git'):
+                self._git.close()
 
     def is_write_locked(self):
         return (self._lock_mode == 'w')
@@ -214,7 +189,7 @@ class GitRepository(ForeignRepository):
         return default_mapping
 
     def make_working_trees(self):
-        return not self._git.get_config().get_boolean(("core", ), "bare")
+        raise NotImplementedError(self.make_working_trees)
 
     def revision_graph_can_have_wrong_parents(self):
         return False
@@ -251,9 +226,7 @@ class LocalGitRepository(GitRepository):
         :param lossy: Whether to discard data that can not be natively
             represented, when pushing to a foreign VCS
         """
-        from .commit import (
-            GitCommitBuilder,
-            )
+        from .commit import GitCommitBuilder
         builder = GitCommitBuilder(
             self, parents, config, timestamp, timezone, committer, revprops,
             revision_id, lossy)
@@ -308,12 +281,10 @@ class LocalGitRepository(GitRepository):
                 except ValueError:
                     raise errors.RevisionNotPresent((fileid, revid), self)
                 try:
-                    obj = tree_lookup_path(
+                    mode, item_id = tree_lookup_path(
                         self._git.object_store.__getitem__, root_tree,
                         encode_git_path(path))
-                    if isinstance(obj, tuple):
-                        (mode, item_id) = obj
-                        obj = self._git.object_store[item_id]
+                    obj = self._git.object_store[item_id]
                 except KeyError:
                     raise errors.RevisionNotPresent((fileid, revid), self)
                 else:
@@ -326,7 +297,7 @@ class LocalGitRepository(GitRepository):
 
     def gather_stats(self, revid=None, committers=None):
         """See Repository.gather_stats()."""
-        result = super(LocalGitRepository, self).gather_stats(
+        result = super().gather_stats(
             revid, committers)
         revs = []
         for sha in self._git.object_store:
@@ -441,10 +412,10 @@ class LocalGitRepository(GitRepository):
             mapping = self.get_mapping()
         if foreign_revid == ZERO_SHA:
             return _mod_revision.NULL_REVISION
-        commit = self._git.object_store.peel_sha(foreign_revid)
-        if not isinstance(commit, Commit):
-            raise NotCommitError(commit.id)
-        revid = mapping.get_revision_id(commit)
+        unpeeled, peeled = peel_sha(self._git.object_store, foreign_revid)
+        if not isinstance(peeled, Commit):
+            raise NotCommitError(peeled.id)
+        revid = mapping.get_revision_id(peeled)
         # FIXME: check testament before doing this?
         return revid
 
@@ -556,10 +527,8 @@ class LocalGitRepository(GitRepository):
     def set_make_working_trees(self, trees):
         raise errors.UnsupportedOperation(self.set_make_working_trees, self)
 
-    def fetch_objects(self, determine_wants, graph_walker, resolve_ext_ref,
-                      progress=None, limit=None):
-        return self._git.fetch_objects(determine_wants, graph_walker, progress,
-                                       limit=limit)
+    def make_working_trees(self):
+        return not self._git.get_config().get_boolean(("core", ), "bare")
 
 
 class GitRepositoryFormat(repository.RepositoryFormat):
@@ -583,6 +552,8 @@ class GitRepositoryFormat(repository.RepositoryFormat):
     supports_custom_revision_properties = False
     records_per_file_revision = False
     supports_multiple_authors = False
+    supports_ghosts = False
+    supports_chks = False
 
     @property
     def _matchingcontroldir(self):
@@ -602,9 +573,7 @@ class GitRepositoryFormat(repository.RepositoryFormat):
         return target_repo_format.rich_root_data
 
     def get_foreign_tests_repository_factory(self):
-        from .tests.test_repository import (
-            ForeignTestsRepositoryFactory,
-            )
+        from .tests.test_repository import ForeignTestsRepositoryFactory
         return ForeignTestsRepositoryFactory()
 
     def network_name(self):
